lxm3.xm\_cluster.SingularityOptions
===================================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: SingularityOptions

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SingularityOptions.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SingularityOptions.bind
      ~SingularityOptions.extra_options
   
   